function h=masrat(rh,t)
% masrat  - Determine the mass ratio of H2O/dry air
% function h=masrat(rh,t)
% Argument List:
% Argument   Gives
%   rh     the relative humidity as a fraction.
%   t      the temperature in the units of Tdeg.
% h is the mass ratio of water to dry air.
% Ex: humidity
%     masrat(.5,50)
x=molrat(rh,t);
h=x*18.016/28.85264;
